==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/SlowStochasticOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { SlowStochasticOscillatorIndicatorDescription } from "./SlowStochasticOscillatorIndicatorDescription";
/**
 * @hidden
 */
var SlowStochasticOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SlowStochasticOscillatorIndicatorDescriptionMetadata, _super);
    function SlowStochasticOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SlowStochasticOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (SlowStochasticOscillatorIndicatorDescriptionMetadata.a == null) {
            SlowStochasticOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SlowStochasticOscillatorIndicatorDescriptionMetadata.c(SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.j(SlowStochasticOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
    };
    SlowStochasticOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    SlowStochasticOscillatorIndicatorDescriptionMetadata.d = function (a) {
        SlowStochasticOscillatorIndicatorDescriptionMetadata.b(a);
        a.aa("SlowStochasticOscillatorIndicator", function () { return new SlowStochasticOscillatorIndicatorDescription(); });
        a.z("SlowStochasticOscillatorIndicator", SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
    };
    SlowStochasticOscillatorIndicatorDescriptionMetadata.$t = markType(SlowStochasticOscillatorIndicatorDescriptionMetadata, 'SlowStochasticOscillatorIndicatorDescriptionMetadata');
    SlowStochasticOscillatorIndicatorDescriptionMetadata.a = null;
    return SlowStochasticOscillatorIndicatorDescriptionMetadata;
}(Base));
export { SlowStochasticOscillatorIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SlowStochasticOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { SlowStochasticOscillatorIndicatorDescription } from "./SlowStochasticOscillatorIndicatorDescription";
/**
 * @hidden
 */
var SlowStochasticOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SlowStochasticOscillatorIndicatorDescriptionMetadata, _super);
    function SlowStochasticOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SlowStochasticOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (SlowStochasticOscillatorIndicatorDescriptionMetadata.a == null) {
            SlowStochasticOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SlowStochasticOscillatorIndicatorDescriptionMetadata.c(SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.k(SlowStochasticOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.aa(SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
    };
    SlowStochasticOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    SlowStochasticOscillatorIndicatorDescriptionMetadata.d = function (a) {
        SlowStochasticOscillatorIndicatorDescriptionMetadata.b(a);
        a.ac("SlowStochasticOscillatorIndicator", function () { return new SlowStochasticOscillatorIndicatorDescription(); });
        a.ab("SlowStochasticOscillatorIndicator", SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
    };
    SlowStochasticOscillatorIndicatorDescriptionMetadata.$t = markType(SlowStochasticOscillatorIndicatorDescriptionMetadata, 'SlowStochasticOscillatorIndicatorDescriptionMetadata');
    SlowStochasticOscillatorIndicatorDescriptionMetadata.a = null;
    return SlowStochasticOscillatorIndicatorDescriptionMetadata;
}(Base));
export { SlowStochasticOscillatorIndicatorDescriptionMetadata };
